==> zio-aws-ec2_2.12-5.17.103.1-sources.jar: zio/aws/ec2/model/SnapshotTierStatus.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  Integer,
  MillisecondDateTime,
  VolumeId,
  SnapshotId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class SnapshotTierStatus(
    snapshotId: Option[SnapshotId] = None,
    volumeId: Option[VolumeId] = None,
    status: Option[zio.aws.ec2.model.SnapshotState] = None,
    ownerId: Option[String] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None,
    storageTier: Option[zio.aws.ec2.model.StorageTier] = None,
    lastTieringStartTime: Option[MillisecondDateTime] = None,
    lastTieringProgress: Option[Integer] = None,
    lastTieringOperationStatus: Option[
      zio.aws.ec2.model.TieringOperationStatus
    ] = None,
    lastTieringOperationStatusDetail: Option[String] = None,
    archivalCompleteTime: Option[MillisecondDateTime] = None,
    restoreExpiryTime: Option[MillisecondDateTime] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SnapshotTierStatus = {
    import SnapshotTierStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
      .builder()
      .optionallyWith(
        snapshotId.map(value => SnapshotId.unwrap(value): java.lang.String)
      )(_.snapshotId)
      .optionallyWith(
        volumeId.map(value => VolumeId.unwrap(value): java.lang.String)
      )(_.volumeId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(storageTier.map(value => value.unwrap))(_.storageTier)
      .optionallyWith(
        lastTieringStartTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.lastTieringStartTime)
      .optionallyWith(
        lastTieringProgress.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.lastTieringProgress)
      .optionallyWith(lastTieringOperationStatus.map(value => value.unwrap))(
        _.lastTieringOperationStatus
      )
      .optionallyWith(
        lastTieringOperationStatusDetail.map(value => value: java.lang.String)
      )(_.lastTieringOperationStatusDetail)
      .optionallyWith(
        archivalCompleteTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.archivalCompleteTime)
      .optionallyWith(
        restoreExpiryTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.restoreExpiryTime)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SnapshotTierStatus.ReadOnly =
    zio.aws.ec2.model.SnapshotTierStatus.wrap(buildAwsValue())
}
object SnapshotTierStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SnapshotTierStatus =
      zio.aws.ec2.model.SnapshotTierStatus(
        snapshotId.map(value => value),
        volumeId.map(value => value),
        status.map(value => value),
        ownerId.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        storageTier.map(value => value),
        lastTieringStartTime.map(value => value),
        lastTieringProgress.map(value => value),
        lastTieringOperationStatus.map(value => value),
        lastTieringOperationStatusDetail.map(value => value),
        archivalCompleteTime.map(value => value),
        restoreExpiryTime.map(value => value)
      )
    def snapshotId: Option[SnapshotId]
    def volumeId: Option[VolumeId]
    def status: Option[zio.aws.ec2.model.SnapshotState]
    def ownerId: Option[String]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def storageTier: Option[zio.aws.ec2.model.StorageTier]
    def lastTieringStartTime: Option[MillisecondDateTime]
    def lastTieringProgress: Option[Integer]
    def lastTieringOperationStatus
        : Option[zio.aws.ec2.model.TieringOperationStatus]
    def lastTieringOperationStatusDetail: Option[String]
    def archivalCompleteTime: Option[MillisecondDateTime]
    def restoreExpiryTime: Option[MillisecondDateTime]
    def getSnapshotId: ZIO[Any, AwsError, SnapshotId] =
      AwsError.unwrapOptionField("snapshotId", snapshotId)
    def getVolumeId: ZIO[Any, AwsError, VolumeId] =
      AwsError.unwrapOptionField("volumeId", volumeId)
    def getStatus: ZIO[Any, AwsError, zio.aws.ec2.model.SnapshotState] =
      AwsError.unwrapOptionField("status", status)
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getStorageTier: ZIO[Any, AwsError, zio.aws.ec2.model.StorageTier] =
      AwsError.unwrapOptionField("storageTier", storageTier)
    def getLastTieringStartTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("lastTieringStartTime", lastTieringStartTime)
    def getLastTieringProgress: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("lastTieringProgress", lastTieringProgress)
    def getLastTieringOperationStatus
        : ZIO[Any, AwsError, zio.aws.ec2.model.TieringOperationStatus] =
      AwsError.unwrapOptionField(
        "lastTieringOperationStatus",
        lastTieringOperationStatus
      )
    def getLastTieringOperationStatusDetail: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "lastTieringOperationStatusDetail",
        lastTieringOperationStatusDetail
      )
    def getArchivalCompleteTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("archivalCompleteTime", archivalCompleteTime)
    def getRestoreExpiryTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("restoreExpiryTime", restoreExpiryTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ) extends zio.aws.ec2.model.SnapshotTierStatus.ReadOnly {
    override val snapshotId: Option[SnapshotId] = scala
      .Option(impl.snapshotId())
      .map(value => zio.aws.ec2.model.primitives.SnapshotId(value))
    override val volumeId: Option[VolumeId] = scala
      .Option(impl.volumeId())
      .map(value => zio.aws.ec2.model.primitives.VolumeId(value))
    override val status: Option[zio.aws.ec2.model.SnapshotState] = scala
      .Option(impl.status())
      .map(value => zio.aws.ec2.model.SnapshotState.wrap(value))
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
    override val storageTier: Option[zio.aws.ec2.model.StorageTier] = scala
      .Option(impl.storageTier())
      .map(value => zio.aws.ec2.model.StorageTier.wrap(value))
    override val lastTieringStartTime: Option[MillisecondDateTime] = scala
      .Option(impl.lastTieringStartTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
    override val lastTieringProgress: Option[Integer] = scala
      .Option(impl.lastTieringProgress())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val lastTieringOperationStatus
        : Option[zio.aws.ec2.model.TieringOperationStatus] = scala
      .Option(impl.lastTieringOperationStatus())
      .map(value => zio.aws.ec2.model.TieringOperationStatus.wrap(value))
    override val lastTieringOperationStatusDetail: Option[String] = scala
      .Option(impl.lastTieringOperationStatusDetail())
      .map(value => value: String)
    override val archivalCompleteTime: Option[MillisecondDateTime] = scala
      .Option(impl.archivalCompleteTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
    override val restoreExpiryTime: Option[MillisecondDateTime] = scala
      .Option(impl.restoreExpiryTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ): zio.aws.ec2.model.SnapshotTierStatus.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.157.2-sources.jar: zio/aws/ec2/model/SnapshotTierStatus.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  Integer,
  MillisecondDateTime,
  VolumeId,
  SnapshotId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class SnapshotTierStatus(
    snapshotId: Option[SnapshotId] = None,
    volumeId: Option[VolumeId] = None,
    status: Option[zio.aws.ec2.model.SnapshotState] = None,
    ownerId: Option[String] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None,
    storageTier: Option[zio.aws.ec2.model.StorageTier] = None,
    lastTieringStartTime: Option[MillisecondDateTime] = None,
    lastTieringProgress: Option[Integer] = None,
    lastTieringOperationStatus: Option[
      zio.aws.ec2.model.TieringOperationStatus
    ] = None,
    lastTieringOperationStatusDetail: Option[String] = None,
    archivalCompleteTime: Option[MillisecondDateTime] = None,
    restoreExpiryTime: Option[MillisecondDateTime] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SnapshotTierStatus = {
    import SnapshotTierStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
      .builder()
      .optionallyWith(
        snapshotId.map(value => SnapshotId.unwrap(value): java.lang.String)
      )(_.snapshotId)
      .optionallyWith(
        volumeId.map(value => VolumeId.unwrap(value): java.lang.String)
      )(_.volumeId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(storageTier.map(value => value.unwrap))(_.storageTier)
      .optionallyWith(
        lastTieringStartTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.lastTieringStartTime)
      .optionallyWith(
        lastTieringProgress.map(value => value: java.lang.Integer)
      )(_.lastTieringProgress)
      .optionallyWith(lastTieringOperationStatus.map(value => value.unwrap))(
        _.lastTieringOperationStatus
      )
      .optionallyWith(
        lastTieringOperationStatusDetail.map(value => value: java.lang.String)
      )(_.lastTieringOperationStatusDetail)
      .optionallyWith(
        archivalCompleteTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.archivalCompleteTime)
      .optionallyWith(
        restoreExpiryTime.map(value =>
          MillisecondDateTime.unwrap(value): Instant
        )
      )(_.restoreExpiryTime)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SnapshotTierStatus.ReadOnly =
    zio.aws.ec2.model.SnapshotTierStatus.wrap(buildAwsValue())
}
object SnapshotTierStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SnapshotTierStatus =
      zio.aws.ec2.model.SnapshotTierStatus(
        snapshotId.map(value => value),
        volumeId.map(value => value),
        status.map(value => value),
        ownerId.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        storageTier.map(value => value),
        lastTieringStartTime.map(value => value),
        lastTieringProgress.map(value => value),
        lastTieringOperationStatus.map(value => value),
        lastTieringOperationStatusDetail.map(value => value),
        archivalCompleteTime.map(value => value),
        restoreExpiryTime.map(value => value)
      )
    def snapshotId: Option[SnapshotId]
    def volumeId: Option[VolumeId]
    def status: Option[zio.aws.ec2.model.SnapshotState]
    def ownerId: Option[String]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def storageTier: Option[zio.aws.ec2.model.StorageTier]
    def lastTieringStartTime: Option[MillisecondDateTime]
    def lastTieringProgress: Option[Integer]
    def lastTieringOperationStatus
        : Option[zio.aws.ec2.model.TieringOperationStatus]
    def lastTieringOperationStatusDetail: Option[String]
    def archivalCompleteTime: Option[MillisecondDateTime]
    def restoreExpiryTime: Option[MillisecondDateTime]
    def getSnapshotId: ZIO[Any, AwsError, SnapshotId] =
      AwsError.unwrapOptionField("snapshotId", snapshotId)
    def getVolumeId: ZIO[Any, AwsError, VolumeId] =
      AwsError.unwrapOptionField("volumeId", volumeId)
    def getStatus: ZIO[Any, AwsError, zio.aws.ec2.model.SnapshotState] =
      AwsError.unwrapOptionField("status", status)
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getStorageTier: ZIO[Any, AwsError, zio.aws.ec2.model.StorageTier] =
      AwsError.unwrapOptionField("storageTier", storageTier)
    def getLastTieringStartTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("lastTieringStartTime", lastTieringStartTime)
    def getLastTieringProgress: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("lastTieringProgress", lastTieringProgress)
    def getLastTieringOperationStatus
        : ZIO[Any, AwsError, zio.aws.ec2.model.TieringOperationStatus] =
      AwsError.unwrapOptionField(
        "lastTieringOperationStatus",
        lastTieringOperationStatus
      )
    def getLastTieringOperationStatusDetail: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "lastTieringOperationStatusDetail",
        lastTieringOperationStatusDetail
      )
    def getArchivalCompleteTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("archivalCompleteTime", archivalCompleteTime)
    def getRestoreExpiryTime: ZIO[Any, AwsError, MillisecondDateTime] =
      AwsError.unwrapOptionField("restoreExpiryTime", restoreExpiryTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ) extends zio.aws.ec2.model.SnapshotTierStatus.ReadOnly {
    override val snapshotId: Option[SnapshotId] = scala
      .Option(impl.snapshotId())
      .map(value => zio.aws.ec2.model.primitives.SnapshotId(value))
    override val volumeId: Option[VolumeId] = scala
      .Option(impl.volumeId())
      .map(value => zio.aws.ec2.model.primitives.VolumeId(value))
    override val status: Option[zio.aws.ec2.model.SnapshotState] = scala
      .Option(impl.status())
      .map(value => zio.aws.ec2.model.SnapshotState.wrap(value))
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
    override val storageTier: Option[zio.aws.ec2.model.StorageTier] = scala
      .Option(impl.storageTier())
      .map(value => zio.aws.ec2.model.StorageTier.wrap(value))
    override val lastTieringStartTime: Option[MillisecondDateTime] = scala
      .Option(impl.lastTieringStartTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
    override val lastTieringProgress: Option[Integer] =
      scala.Option(impl.lastTieringProgress()).map(value => value: Integer)
    override val lastTieringOperationStatus
        : Option[zio.aws.ec2.model.TieringOperationStatus] = scala
      .Option(impl.lastTieringOperationStatus())
      .map(value => zio.aws.ec2.model.TieringOperationStatus.wrap(value))
    override val lastTieringOperationStatusDetail: Option[String] = scala
      .Option(impl.lastTieringOperationStatusDetail())
      .map(value => value: String)
    override val archivalCompleteTime: Option[MillisecondDateTime] = scala
      .Option(impl.archivalCompleteTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
    override val restoreExpiryTime: Option[MillisecondDateTime] = scala
      .Option(impl.restoreExpiryTime())
      .map(value => zio.aws.ec2.model.primitives.MillisecondDateTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotTierStatus
  ): zio.aws.ec2.model.SnapshotTierStatus.ReadOnly = new Wrapper(impl)
}
